@@ -14,3 +14,7 @@ class FileType(str, Enum):
     csv = "csv"
     conll = "conll"  # for tagging task such as named entity recognition
     datalab = "datalab"
+
+    @staticmethod
+    def list():
+        return list(map(lambda c: c.value, FileType))
